cbchelpers
==============================
[//]: # (Badges)
[![GitHub Actions Build Status](https://github.com/REPLACE_WITH_OWNER_ACCOUNT/cbchelpers/workflows/CI/badge.svg)](https://github.com/REPLACE_WITH_OWNER_ACCOUNT/cbchelpers/actions?query=workflow%3ACI)

[//]: <[![codecov](https://codecov.io/gh/REPLACE_WITH_OWNER_ACCOUNT/cbchelpers/branch/main/graph/badge.svg)](https://codecov.io/gh/REPLACE_WITH_OWNER_ACCOUNT/cbchelpers/branch/main)>

Various functions and methods to facilitate my work

### Installation

```python
pip install cbchelpers
```

### Copyright

Copyright (c) 2023, Florian Joerg


#### Acknowledgements
 
Project based on the 
[Computational Molecular Science Python Cookiecutter](https://github.com/molssi/cookiecutter-cms) version 1.1.
